@@ -39,6 +39,8 @@ use std::sync::Arc;
 use arrow::io::ipc::write::WriteOptions;
 use arrow::io::ipc::{read, write};
 use polars_core::prelude::*;
+#[cfg(feature = "serde")]
+use serde::{Deserialize, Serialize};
 
 use super::{finish_reader, ArrowReader, ArrowResult};
 use crate::predicates::PhysicalIoExpr;
@@ -268,29 +270,28 @@ impl<R: MmapBytesReader> SerReader<R> for IpcReader<R> {
 #[must_use]
 pub struct IpcWriter<W> {
     writer: W,
-    compression: Option<write::Compression>,
+    compression: Option<IpcCompression>,
 }
 
 use polars_core::frame::ArrowChunk;
-pub use write::Compression as IpcCompression;
 
 use crate::mmap::MmapBytesReader;
 use crate::RowCount;
 
 impl<W: Write> IpcWriter<W> {
     /// Set the compression used. Defaults to None.
-    pub fn with_compression(mut self, compression: Option<write::Compression>) -> Self {
+    pub fn with_compression(mut self, compression: Option<IpcCompression>) -> Self {
         self.compression = compression;
         self
     }
 
-    pub fn batched(&mut self, schema: &Schema) -> PolarsResult<BatchedWriter<&mut W>> {
+    pub fn batched(self, schema: &Schema) -> PolarsResult<BatchedWriter<W>> {
         let mut writer = write::FileWriter::new(
-            &mut self.writer,
+            self.writer,
             schema.to_arrow(),
             None,
             WriteOptions {
-                compression: self.compression,
+                compression: self.compression.map(|c| c.into()),
             },
         );
         writer.start()?;
@@ -313,10 +314,10 @@ where
     fn finish(&mut self, df: &mut DataFrame) -> PolarsResult<()> {
         let mut ipc_writer = write::FileWriter::try_new(
             &mut self.writer,
-            &df.schema().to_arrow(),
+            df.schema().to_arrow(),
             None,
             WriteOptions {
-                compression: self.compression,
+                compression: self.compression.map(|c| c.into()),
             },
         )?;
         df.rechunk();
@@ -354,8 +355,28 @@ impl<W: Write> BatchedWriter<W> {
     }
 }
 
+/// Compression codec
+#[derive(Debug, Clone, Copy, PartialEq, Eq, Hash, Default)]
+#[cfg_attr(feature = "serde", derive(Serialize, Deserialize))]
+pub enum IpcCompression {
+    /// LZ4 (framed)
+    LZ4,
+    /// ZSTD
+    #[default]
+    ZSTD,
+}
+
+impl From<IpcCompression> for write::Compression {
+    fn from(value: IpcCompression) -> Self {
+        match value {
+            IpcCompression::LZ4 => write::Compression::LZ4,
+            IpcCompression::ZSTD => write::Compression::ZSTD,
+        }
+    }
+}
+
 pub struct IpcWriterOption {
-    compression: Option<write::Compression>,
+    compression: Option<IpcCompression>,
     extension: PathBuf,
 }
 
@@ -368,7 +389,7 @@ impl IpcWriterOption {
     }
 
     /// Set the compression used. Defaults to None.
-    pub fn with_compression(mut self, compression: Option<write::Compression>) -> Self {
+    pub fn with_compression(mut self, compression: Option<IpcCompression>) -> Self {
         self.compression = compression;
         self
     }
@@ -400,7 +421,6 @@ impl WriterFactory for IpcWriterOption {
 mod test {
     use std::io::Cursor;
 
-    use arrow::io::ipc::write;
     use polars_core::df;
     use polars_core::prelude::*;
 
@@ -494,11 +514,7 @@ mod test {
     fn test_write_with_compression() {
         let mut df = create_df();
 
-        let compressions = vec![
-            None,
-            Some(write::Compression::LZ4),
-            Some(write::Compression::ZSTD),
-        ];
+        let compressions = vec![None, Some(IpcCompression::LZ4), Some(IpcCompression::ZSTD)];
 
         for compression in compressions.into_iter() {
             let mut buf: Cursor<Vec<u8>> = Cursor::new(Vec::new());
