@@ -3,17 +3,21 @@ use std::borrow::Cow;
 use std::path::PathBuf;
 use std::sync::Arc;
 
+#[cfg(feature = "parquet")]
+use polars_core::cloud::CloudOptions;
 use polars_core::frame::explode::MeltArgs;
 use polars_core::prelude::*;
 use polars_utils::arena::{Arena, Node};
 
 use crate::logical_plan::functions::FunctionNode;
 use crate::logical_plan::schema::{det_join_schema, FileInfo};
+#[cfg(feature = "csv-file")]
+use crate::logical_plan::CsvParserOptions;
 #[cfg(feature = "ipc")]
 use crate::logical_plan::IpcScanOptionsInner;
 #[cfg(feature = "parquet")]
 use crate::logical_plan::ParquetOptions;
-use crate::logical_plan::{det_melt_schema, Context, CsvParserOptions};
+use crate::logical_plan::{det_melt_schema, Context};
 use crate::prelude::*;
 use crate::utils::{aexprs_to_schema, PushNode};
 
@@ -72,6 +76,7 @@ pub enum ALogicalPlan {
         output_schema: Option<SchemaRef>,
         predicate: Option<Node>,
         options: ParquetOptions,
+        cloud_options: Option<CloudOptions>,
     },
     DataFrameScan {
         df: Arc<DataFrame>,
@@ -375,6 +380,7 @@ impl ALogicalPlan {
                 output_schema,
                 predicate,
                 options,
+                cloud_options,
                 ..
             } => {
                 let mut new_predicate = None;
@@ -388,6 +394,7 @@ impl ALogicalPlan {
                     output_schema: output_schema.clone(),
                     predicate: new_predicate,
                     options: options.clone(),
+                    cloud_options: cloud_options.clone(),
                 }
             }
             #[cfg(feature = "csv-file")]
